@@ -4,8 +4,8 @@ from ._preprocessing import (
     compute_mask,
     reorganize_array_dimensions,
     reorganize_array_dimensions_from_files,
-    global_image_equalization,
-    local_image_equalization,
+    global_contrast_enhancement,
+    local_contrast_enhancement,
     normalize_intensity,
     segment_stardist,
     segment_stardist_from_files,
@@ -24,8 +24,8 @@ __all__ = [
     "compute_mask",
     "reorganize_array_dimensions",
     "reorganize_array_dimensions_from_files",
-    "global_image_equalization",
-    "local_image_equalization",
+    "global_contrast_enhancement",
+    "local_contrast_enhancement",
     "normalize_intensity",
     "segment_stardist",
     "segment_stardist_from_files",
