@@ -18,7 +18,7 @@ from tapenade.preprocessing._axis_alignment import (
 from tapenade.preprocessing._intensity_normalization import (
     _normalize_intensity,
 )
-from tapenade.preprocessing._local_equalization import _local_equalization
+from tapenade.preprocessing._local_contrast_enhancement import _local_contrast_enhancement
 from tapenade.preprocessing._segmentation import (
     _load_model,
     _purge_gpu_memory,
@@ -40,7 +40,7 @@ from tapenade.preprocessing._thresholding import _compute_mask
 In typical order:
     1. making array isotropic
     2. compute mask
-    3. local image equalization
+    3. local/global image contrast enhancement
     4. segmentation, e.g with StarDist
     (5. spatial registration, not covered here)
     (6. temporal registration, not covered here)
@@ -50,7 +50,7 @@ In typical order:
 
 
 def isotropize_and_normalize(
-    image, mask, labels, scale, sigma: float = None, pos_ref: int = 0
+    image, mask, labels, scale, sigma: float = None, pos_ref: int = 0,wavelength_dependent_normalization:bool=False
 ):
     """
     Make an image isotropic and normalized with respect to a reference channel. Works for multichannel images (ZCYX convention) or single channel images (ZYX convention).
@@ -74,6 +74,7 @@ def isotropize_and_normalize(
     norm_image : np.array
         normalized and isotropic image
     """
+    list_wavelengths = [405, 488, 555, 647] 
 
     if len(image.shape) > 3:  # if multichannel image
         nb_channels = image.shape[1]
@@ -114,22 +115,41 @@ def isotropize_and_normalize(
         norm_image = np.zeros_like(iso_image)
         for ch_float in liste_float_channels:
             channel = iso_image[:, ch_float, :, :]
-            channel_norm = normalize_intensity(
-                image=channel,
+            if wavelength_dependent_normalization==False:
+                channel_norm = normalize_intensity(
+                    image=channel,
+                    ref_image=ref_channel,
+                    mask=mask_iso,
+                    labels=seg_iso,
+                    sigma=sigma,
+                )
+            else :    
+                channel_norm = normalize_intensity(
+                    image=channel,
+                    ref_image=ref_channel,
+                    mask=mask_iso,
+                    labels=seg_iso,
+                    sigma=sigma,
+                    image_wavelength=list_wavelengths[ch_float]
+                )
+            norm_image[:, ch_float, :, :] = channel_norm
+        if wavelength_dependent_normalization==False:
+            ref_norm = normalize_intensity(
+                image=ref_channel,
                 ref_image=ref_channel,
                 mask=mask_iso,
                 labels=seg_iso,
                 sigma=sigma,
             )
-
-            norm_image[:, ch_float, :, :] = channel_norm
-        ref_norm = normalize_intensity(
-            image=ref_channel,
-            ref_image=ref_channel,
-            mask=mask_iso,
-            labels=seg_iso,
-            sigma=sigma,
-        )
+        else : 
+            ref_norm = normalize_intensity(
+                image=ref_channel,
+                ref_image=ref_channel,
+                mask=mask_iso,
+                labels=seg_iso,
+                sigma=sigma,
+                image_wavelength=list_wavelengths[pos_ref]
+            )
         norm_image[:, pos_ref, :, :] = ref_norm
 
     else:  # 3D data, one channel
@@ -407,11 +427,12 @@ def _load_reorganize_and_save_to_file(
 
     if bool_seperate_channels:
         # save each channel to a separate folder
-        for index, (array_channel, output_folder) in enumerate(
+        for ind_ch, (array_channel, output_folder) in enumerate(
             zip(array_result, output_folders, strict=False)
         ):
+            ind_ch_ = ind_ch + 1
             tifffile.imwrite(
-                f"{output_folder}/{array_file}_ch{index:>02}",
+                f"{output_folder}/reorganized_{index:>04}_ch{ind_ch_:>02}.tif",
                 array_channel,
                 **compress_params,
             )
@@ -443,7 +464,7 @@ def reorganize_array_dimensions_from_files(
 
     # open all array files using the multithreading library and reorganize the dimensions
     with concurrent.futures.ThreadPoolExecutor(max_workers=n_jobs) as executor:
-        tqdm(
+        list(tqdm(
             executor.map(
                 multithreaded_function,
                 array_files,
@@ -451,7 +472,7 @@ def reorganize_array_dimensions_from_files(
             ),
             total=len(array_files),
             desc="Reorganizing array",
-        )
+        ))
 
 
 def compute_mask(
@@ -462,6 +483,7 @@ def compute_mask(
     post_processing_method: str = "fill_holes",
     keep_largest_cc: bool = True,
     registered_image: bool = False,
+    n_erosion_steps: int = 0,
     n_jobs: int = -1,
 ) -> np.ndarray:
     """
@@ -474,11 +496,11 @@ def compute_mask(
     - sigma_blur: float, standard deviation of the Gaussian blur. Should typically be
       around 1/3 of the typical object diameter.
     - threshold_factor: float, factor to multiply the threshold (default: 1)
-    - post_processing_method: str, method to use for post-processing the mask. Can be 'convex_hull' to compute
-      the convex hull of the mask, 'fill_holes' to fill holes in the mask, or 'none' to skip post-processing
-      (default: 'fill_holes')
+    - post_processing_method: str, Can be 'convex_hull' to compute the convex hull of the mask,
+      'fill_holes' to fill holes each plane separately, or 'none' to skip post-processing (default: 'fill_holes')
     - keep_largest_cc: bool, set to True to keep only the largest connected component in the mask (default: True)
     - n_jobs: int, number of parallel jobs to run (-1 for using all available CPUs)
+    - n_erosion_steps: int, number of erosion steps to apply to the mask after post-processing.
 
     Returns:
     - mask: numpy array, binary mask of the same shape as the input image
@@ -495,6 +517,7 @@ def compute_mask(
             post_processing_method=post_processing_method,
             keep_largest_cc=keep_largest_cc,
             registered_image=registered_image,
+            n_erosion_steps=n_erosion_steps,
         )
 
         if n_jobs == 1:
@@ -527,12 +550,13 @@ def compute_mask(
             post_processing_method=post_processing_method,
             keep_largest_cc=keep_largest_cc,
             registered_image=registered_image,
+            n_erosion_steps=n_erosion_steps,
         )
 
     return np.array(mask)
 
 
-def global_image_equalization(
+def global_contrast_enhancement(
     image: np.ndarray,
     perc_low: float,
     perc_high: float,
@@ -540,19 +564,19 @@ def global_image_equalization(
     n_jobs: int = -1,
 ) -> np.ndarray:
     """
-    Performs global image equalization on either a single image or a temporal stack of images.
+    Performs global contrast enhancement on either a single image or a temporal stack of images.
     Stretches the image histogram by remapping intesities in the range [perc_low, perc_high] to the range [0, 1].
     This helps to enhance the contrast and improve the visibility of structures in the image.
 
     Parameters:
     - image: numpy array, input image or temporal stack of images
-    - perc_low: float, lower percentile for intensity equalization (between 0 and 100)
-    - perc_high: float, upper percentile for intensity equalization (between 0 and 100)
+    - perc_low: float, lower percentile for intensity mapping (between 0 and 100)
+    - perc_high: float, upper percentile for intensity mapping (between 0 and 100)
     - mask: numpy array, binary mask used to set the background to zero (optional)
     - n_jobs: int, number of parallel jobs to use (not used currently as the function is parallelized internally)
 
     Returns:
-    - image_norm: numpy array, equalized image or stack of equalized images
+    - image_norm: numpy array, enhanced image or stack of enhanced images
     """
 
     is_temporal = image.ndim == 4
@@ -573,7 +597,7 @@ def global_image_equalization(
     return np.clip(image_norm, 0, 1)
 
 
-def _local_equalization_parallel(
+def _local_contrast_enhancement_parallel(
     tuple_input: tuple[np.ndarray, np.ndarray],
     box_size: int,
     perc_low: float,
@@ -582,7 +606,7 @@ def _local_equalization_parallel(
 
     image, mask = tuple_input
 
-    image_norm = _local_equalization(
+    image_norm = _local_contrast_enhancement(
         image,
         box_size=box_size,
         perc_low=perc_low,
@@ -593,7 +617,7 @@ def _local_equalization_parallel(
     return image_norm
 
 
-def local_image_equalization(
+def local_contrast_enhancement(
     image: np.ndarray,
     box_size: int,
     perc_low: float,
@@ -602,21 +626,21 @@ def local_image_equalization(
     n_jobs: int = -1,
 ) -> np.ndarray:
     """
-    Performs local image equalization on either a single image or a temporal stack of images.
+    Performs local image contrast enhancement on either a single image or a temporal stack of images.
     Stretches the image histogram in local neighborhoods by remapping intesities in the range
     [perc_low, perc_high] to the range [0, 1].
     This helps to enhance the contrast and improve the visibility of structures in the image.
 
     Parameters:
     - image: numpy array, input image or temporal stack of images
-    - box_size: int, size of the local neighborhood for equalization
-    - perc_low: float, lower percentile for intensity equalization (between 0 and 100)
-    - perc_high: float, upper percentile for intensity equalization (between 0 and 100)
+    - box_size: int, size of the local neighborhood for contrast enhancement
+    - perc_low: float, lower percentile for intensity mapping (between 0 and 100)
+    - perc_high: float, upper percentile for intensity mapping (between 0 and 100)
     - mask: numpy array, binary mask used to set the background to zero (optional)
     - n_jobs: int, number of parallel jobs to use (not used currently as the function is parallelized internally)
 
     Returns:
-    - image_norm: numpy array, equalized image or stack of equalized images
+    - image_norm: numpy array, enahnced image or stack of enahnced images
     """
 
     is_temporal = image.ndim == 4
@@ -628,7 +652,7 @@ def local_image_equalization(
             mask = [None] * image.shape[0]
 
         func_parallel = partial(
-            _local_equalization_parallel,
+            _local_contrast_enhancement_parallel,
             box_size=box_size,
             perc_low=perc_low,
             perc_high=perc_high,
@@ -637,10 +661,10 @@ def local_image_equalization(
         if n_jobs == 1:
             # Sequential processing
             image_norm = [
-                func_parallel(im, mask=ma)
-                for im, ma in tqdm(
+                func_parallel(im_ma)
+                for im_ma in tqdm(
                     zip(image, mask, strict=False),
-                    desc="Local equalization",
+                    desc="Local contrast enhancement",
                     total=image.shape[0],
                 )
             ]
@@ -656,13 +680,13 @@ def local_image_equalization(
                     func_parallel,
                     zip(image, mask, strict=False),
                     max_workers=max_workers,
-                    desc="Local equalization",
+                    desc="Local contrast enhancement",
                     total=image.shape[0],
                 )
             )
     else:
-        # Apply local equalization to the image
-        image_norm = _local_equalization(
+        # Apply local contrast enhancement to the image
+        image_norm = _local_contrast_enhancement(
             image,
             box_size=box_size,
             perc_low=perc_low,
@@ -683,6 +707,7 @@ def normalize_intensity(
     sigma: float = None,
     mask: np.ndarray = None,
     labels: np.ndarray = None,
+    image_wavelength: float = None,
     width: int = 3,
     n_jobs: int = -1,
 ) -> tuple[np.ndarray, np.ndarray]:
@@ -698,6 +723,7 @@ def normalize_intensity(
     - mask: numpy array, binary mask of the sample (default: None)
     - labels: numpy array, labels indicating the instances in which the reference
         signal is expressed (default: None)
+    - image_wavelength: float, wavelength of the image (default: None)
     - width: int, number of neighboring planes to consider for reference plane
         calculation (default: 3)
     - n_jobs: int, number of parallel jobs to use (-1 for all available CPUs, 1 for
@@ -707,7 +733,7 @@ def normalize_intensity(
     - image_norm: numpy array, normalized input image
     - ref_image_norm: numpy array, normalized reference image
     """
-
+    # this is a temporary solution while no continuous fit is implemented
     is_temporal = image.ndim == 4
 
     if is_temporal:
@@ -726,6 +752,7 @@ def normalize_intensity(
                     sigma=sigma,
                     mask=ma,
                     labels=lab,
+                    image_wavelength=image_wavelength,
                     width=width,
                 )
                 for im, ref_im, ma, lab in tqdm(
@@ -742,6 +769,7 @@ def normalize_intensity(
                 sigma=sigma,
                 mask=mask,
                 labels=labels,
+                image_wavelength=image_wavelength,
                 width=width,
             )
 
@@ -765,6 +793,7 @@ def normalize_intensity(
             sigma=sigma,
             mask=mask,
             labels=labels,
+            image_wavelength=image_wavelength,
             width=width,
         )
 
@@ -813,10 +842,10 @@ def segment_stardist(
             thresholds_dict=thresholds_dict,
         )
 
-    from stardist import gputools_available
 
-    if gputools_available():
-        _purge_gpu_memory()
+    # from stardist simport gputools_available
+    # if gputools_available(): # COMMENT FOR NOW
+    #     _purge_gpu_memory()
 
     return labels
 
@@ -1025,7 +1054,7 @@ def align_array_major_axis_from_files(
 
     # open all array files using the multithreading library and crop the results
     with concurrent.futures.ThreadPoolExecutor(max_workers=n_jobs) as executor:
-        tqdm(
+        list(tqdm(
             executor.map(
                 multithreaded_function,
                 array_files,
@@ -1034,7 +1063,7 @@ def align_array_major_axis_from_files(
             ),
             total=len(array_files),
             desc="Aligning array",
-        )
+        ))
 
 
 def crop_array_using_mask(
@@ -1166,7 +1195,7 @@ def crop_array_using_mask_from_files(
     )
     # open all array files using the multithreading library and crop the results
     with concurrent.futures.ThreadPoolExecutor(max_workers=n_jobs) as executor:
-        tqdm(
+        list(tqdm(
             executor.map(
                 multithreaded_function,
                 array_files,
@@ -1174,7 +1203,7 @@ def crop_array_using_mask_from_files(
             ),
             total=len(array_files),
             desc="Cropping array",
-        )
+        ))
 
 
 def _parallel_gaussian_smooth(
@@ -1416,8 +1445,8 @@ def masked_gaussian_smooth_sparse(
     dim_space: int,
     sigmas: Union[float, tuple[float]],
     positions: np.ndarray = None,
-    n_job: int = -1,
-    progress_bars: bool = True,
+    n_jobs: int = -1,
+    progress_bars: bool = False,
 ):
     """
     Smooth sparse data using a gaussian kernel.
@@ -1442,7 +1471,7 @@ def masked_gaussian_smooth_sparse(
         positions of the input array.
     mask : np.ndarray, optional
         Mask to apply to the positions. If None, no mask is applied.
-    n_job : int, optional
+    n_jobs : int, optional
         Number of jobs to run in parallel. If -1, all the available CPUs are used.
         The default is -1.
 
@@ -1456,7 +1485,7 @@ def masked_gaussian_smooth_sparse(
 
     if is_temporal:
 
-        if n_job == 1:
+        if n_jobs == 1:
 
             if positions_is_temporal:
                 return np.array(
@@ -1498,7 +1527,7 @@ def masked_gaussian_smooth_sparse(
                 )
 
                 max_workers = (
-                    cpu_count() if n_job == -1 else min(n_job, cpu_count())
+                    cpu_count() if n_jobs == -1 else min(n_jobs, cpu_count())
                 )
                 result = np.array(
                     process_map(
@@ -1517,7 +1546,7 @@ def masked_gaussian_smooth_sparse(
                 )
 
                 max_workers = (
-                    cpu_count() if n_job == -1 else min(n_job, cpu_count())
+                    cpu_count() if n_jobs == -1 else min(n_jobs, cpu_count())
                 )
                 result = process_map(
                     func,
