@@ -6,7 +6,6 @@ from pathlib import Path
 from xml.dom import minidom
 import tifffile
 import matplotlib.pyplot as plt
-import napari
 import numpy as np
 import registrationtools
 import io
@@ -25,7 +24,6 @@ def extract_positions(path_positions: str):
     path_positions : str
         path to the xml file
     """
-    print(path_positions)
     positions = minidom.parse(
         str(path_positions)
     )  # need to convert the path to a string, otherwise minidom does not work for Windows paths
@@ -141,14 +139,14 @@ def create_folders(
         folder_sample = Path(folder_experiment) / filename_ref
 
         # creates paths for the output files
-        os.mkdir(os.path.join(folder_experiment, filename_ref))
-        os.mkdir(os.path.join(folder_sample, "trsf"))
-        os.mkdir(os.path.join(folder_sample, "raw"))
-        os.mkdir(os.path.join(folder_sample, "registered"))
-        os.mkdir(os.path.join(folder_sample, "fused"))
-        os.mkdir(os.path.join(folder_sample, "weights"))
-        os.mkdir(os.path.join(Path(folder_sample) / "weights", "before_trsf"))
-        os.mkdir(os.path.join(Path(folder_sample) / "weights", "after_trsf"))
+        Path(f"{folder_experiment}/{filename_ref}").mkdir(exist_ok=True)
+        Path(folder_sample / "registered").mkdir(exist_ok=True)
+        Path(folder_sample / "trsf").mkdir(exist_ok=True)
+        Path(folder_sample / "raw").mkdir(exist_ok=True)
+        Path(folder_sample / "fused").mkdir(exist_ok=True)
+        Path(folder_sample / "weights").mkdir(exist_ok=True)
+        Path(folder_sample / "weights" / "before_trsf").mkdir(exist_ok=True)
+        Path(folder_sample / "weights" / "after_trsf").mkdir(exist_ok=True)
 
         image_ref = io.imread(Path(folder_experiment) / f"{filename_ref}.tif")
         image_float = io.imread(
@@ -498,7 +496,6 @@ def register(
         "registration_depth": depth,
         "ordered_init_trsfs": ordered_init_trsfs,
     }
-    print(data)
 
     if save_json != "":
         json_string = json.dumps(data, indent=4)
@@ -536,7 +533,7 @@ def check_napari(
         if True, the images are considered as labels, by default False
 
     """
-
+    import napari
     viewer = napari.Viewer()
     if isinstance(reference_image, (str | Path)):
         if os.path.exists(
@@ -663,7 +660,7 @@ def fuse_sides(
     reference_image: str,
     floating_image: str,
     folder_output: str = "",
-    name_output: str = "fusion",
+    name_output: str = 'fusion.tif',
     slope_coeff: int = 20,
     axis: int = 0,
     input_voxel: list = [1, 1, 1],
@@ -714,8 +711,8 @@ def fuse_sides(
     dtype_input = (
         float_im.dtype
     )  # we wil return an image that has the same dtype as the input image
-    mask_r = compute_mask(image = ref_im,method = 'snp otsu',sigma_blur=sigma_for_mask,threshold_factor=threshold_factor_for_mask,compute_convex_hull=False,registered_image=False)
-    mask_f = compute_mask(image = float_im,method = 'snp otsu',sigma_blur=sigma_for_mask,threshold_factor=threshold_factor_for_mask,compute_convex_hull=False,registered_image=False)
+    mask_r = compute_mask(image = ref_im,method = 'snp otsu',sigma_blur=sigma_for_mask,threshold_factor=threshold_factor_for_mask,registered_image=False)
+    mask_f = compute_mask(image = float_im,method = 'snp otsu',sigma_blur=sigma_for_mask,threshold_factor=threshold_factor_for_mask,registered_image=False)
 
     # we compute the weights as a sigmoid function of the distance to the objective (=cumulative sum of the raw image)
     cumsum_r = np.cumsum(mask_r.astype(int), axis=axis)
@@ -772,7 +769,6 @@ def fuse_sides(
         return fusion
     io.imsave(Path(folder_output) / name_output, fusion.astype(dtype_input))
 
-
 def write_hyperstacks(
     path: str,
     sample_id: str,
@@ -802,7 +798,6 @@ def write_hyperstacks(
     new_image = np.zeros((z, len(channels), y, x))
     for ch in range(len(channels)):
         one_channel = io.imread(Path(path) / f"{sample_id}_{channels[ch]}.tif")
-        print(one_channel.shape)
         new_image[:, ch, :, :] = one_channel
 
     if return_image:
@@ -811,10 +806,8 @@ def write_hyperstacks(
     tifffile.imwrite(
         Path(path) / f"{sample_id}_registered.tif",
         new_image.astype(dtype),
-        imagej=True,
-        compression=("zlib", 1),
-    )  # float16 not compatible with Fiji
-
+    ) 
+    return new_image.astype(dtype)
 
 def add_centermass(landmarks, radius: int = 10, centermass_label: int = 10):
     """
